@@ -1,14 +1,18 @@
-use std::io::{stdout, Write};
+use crate::utils::config::TRIM_OUTPUT;
+use std::{
+	io::{stdout, Write},
+	sync::atomic::Ordering,
+};
 use yansi::{Color, Style};
 
 pub const LABEL_WIDTH: usize = 12;
 
-/// Print a message with a label, add a \r at the end and flush the stdout
+/// Print a message with a label, add a carriage return at the end and flush the stdout
 pub fn print_label<S: Into<String>>(label: OutputLabel, message: S) {
 	print!("{}\r", pretty_output(label, message));
 
 	stdout().flush().unwrap_or_else(|_| {
-		eprintln!("Could not flush stdout");
+		println_label(OutputLabel::Error, "Could not flush stdout");
 	});
 }
 
@@ -43,9 +47,6 @@ pub enum OutputLabel<'a> {
 
 /// Pretty a message with a given label and a given message colour
 pub fn pretty_output<S: Into<String>>(label: OutputLabel, message: S) -> String {
-	let term_width = get_term_width();
-	let message = shorten(message.into(), term_width - LABEL_WIDTH - 1);
-
 	let (label, label_color) = match label {
 		OutputLabel::Error => (String::from("Error"), Color::Red),
 		OutputLabel::Warning => (String::from("Warn"), Color::Yellow),
@@ -56,13 +57,24 @@ pub fn pretty_output<S: Into<String>>(label: OutputLabel, message: S) -> String
 		OutputLabel::None => (String::from(""), Color::White),
 	};
 
-	return format!(
-		"{}{} {}{}",
-		" ".repeat(LABEL_WIDTH - label.len()),
-		Style::new(label_color).bold().paint(label),
-		message,
-		" ".repeat(term_width - LABEL_WIDTH - message.len() - 1),
-	);
+	let term_width = get_term_width();
+	let message = message.into();
+
+	match TRIM_OUTPUT.load(Ordering::Acquire) {
+		true => {
+			let shorten_message = shorten(message, term_width - LABEL_WIDTH - 1);
+
+			format!(
+				"{}{} {}{}",
+				" ".repeat(LABEL_WIDTH - label.len()),
+				Style::new(label_color).bold().paint(label),
+				shorten_message,
+				" ".repeat(term_width - LABEL_WIDTH - shorten_message.len() - 1),
+			)
+		}
+
+		false => format!("{} {}", label, message),
+	}
 }
 
 /// Shortens a message by omitting the middle part and replacing it with '...'
